Package: Moonlight2R
Type: Package
Title: Identify oncogenes and tumor suppressor genes from omics data
Version: 1.11.0
Date:
Authors@R: 
  c(person("Mona", "Nourbakhsh",
           role="aut"),
    person("Astrid", "Saksager",
           role="aut"),
    person("Nikola", "Tom",
           role="aut"),
    person("Katrine", "Meldgård",
           role="aut"),
    person("Anna", "Melidi",
           role="aut"),
    person("Xi Steven", "Chen",
           role="aut"),
    person("Antonio", "Colaprico",
           role="aut"),
    person("Catharina", "Olsen",
           role="aut"),
    person("Alessia", "Campo",
           role=c("aut")),
    person("Matteo", "Tiberti",
           role=c("cre", "aut"),
	   email="tiberti@cancer.dk"),
    person("Elena", "Papaleo",
	   role="aut",
    	   ))
Depends: R (>= 4.5), doParallel, foreach
Imports: parmigene, randomForest, gplots, circlize, RColorBrewer,
        HiveR, clusterProfiler, DOSE, Biobase, grDevices, graphics,
        GEOquery, stats, purrr, RISmed, grid, utils, ComplexHeatmap,
        GenomicRanges, dplyr, fuzzyjoin, rtracklayer, magrittr, qpdf,
        readr, seqminer, stringr, tibble, tidyHeatmap, tidyr,
        AnnotationHub, easyPubMed, org.Hs.eg.db, EpiMix, BiocGenerics,
        ggplot2, ExperimentHub, rlang, withr, data.table, fgsea
Description: The understanding of cancer mechanism requires the
        identification of genes playing a role in the development of
        the pathology and the characterization of their role (notably
        oncogenes and tumor suppressors). We present an updated version
        of the R/bioconductor package called MoonlightR, namely
        Moonlight2R, which returns a list of candidate driver genes for
        specific cancer types on the basis of omics data integration.
        The Moonlight framework contains a primary layer where gene
        expression data and information about biological processes are
        integrated to predict genes called oncogenic mediators, divided
        into putative tumor suppressors and putative oncogenes. This is
        done through functional enrichment analyses, gene regulatory
        networks and upstream regulator analyses to score the
        importance of well-known biological processes with respect to
        the studied cancer type. By evaluating the effect of the
        oncogenic mediators on biological processes or through random
        forests, the primary layer predicts two putative roles for the
        oncogenic mediators: i) tumor suppressor genes (TSGs) and ii)
        oncogenes (OCGs). As gene expression data alone is not enough
        to explain the deregulation of the genes, a second layer of
        evidence is needed. We have automated the integration of a
        secondary mutational layer through new functionalities in
        Moonlight2R. These functionalities analyze mutations in the
        cancer cohort and classifies these into driver and passenger
        mutations using the driver mutation prediction tool,
        CScape-somatic. Those oncogenic mediators with at least one
        driver mutation are retained as the driver genes. As a
        consequence, this methodology does not only identify genes
        playing a dual role (e.g. TSG in one cancer type and OCG in
        another) but also helps in elucidating the biological processes
        underlying their specific roles. In particular, Moonlight2R can
        be used to discover OCGs and TSGs in the same cancer type. This
        may for instance help in answering the question whether some
        genes change role between early stages (I, II) and late stages
        (III, IV). In the future, this analysis could be useful to
        determine the causes of different resistances to
        chemotherapeutic treatments. An additional mechanistic layer
        evaluates if there are mutations affecting the protein
        stability of the transcription factors (TFs) of the TSGs and
        OCGs, as that may have an effect on the expression of the
        genes.
License: GPL-3
biocViews: DNAMethylation, DifferentialMethylation, GeneRegulation,
        GeneExpression, MethylationArray, DifferentialExpression,
        Pathways, Network, Survival, GeneSetEnrichment,
        NetworkEnrichment
Suggests: BiocStyle, knitr, rmarkdown, testthat (>= 3.0.0), devtools,
        roxygen2, png
SystemRequirements: CScapeSomatic
VignetteBuilder: knitr
URL: https://github.com/ELELAB/Moonlight2R
BugReports: https://github.com/ELELAB/Moonlight2R/issues
RoxygenNote: 7.3.3
LazyData: false
Encoding: UTF-8
Config/testthat/edition: 3
Config/pak/sysreqs: libcairo2-dev cmake libfontconfig1-dev
        libfreetype6-dev libglpk-dev libglu1-mesa-dev make texlive
        libbz2-dev libicu-dev libjpeg-dev liblzma-dev libpng-dev
        libuv1-dev libxml2-dev libgl1-mesa-dev libssl-dev perl
        libx11-dev xz-utils zlib1g-dev
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-04-28 13:01:32 UTC
RemoteUrl: https://github.com/bioc/Moonlight2R
RemoteRef: HEAD
RemoteSha: f947d16ced3766bab9e78fc0aac8a4a9e9137319
NeedsCompilation: no
Packaged: 2026-05-30 09:20:46 UTC; root
Author: Mona Nourbakhsh [aut],
  Astrid Saksager [aut],
  Nikola Tom [aut],
  Katrine Meldgård [aut],
  Anna Melidi [aut],
  Xi Steven Chen [aut],
  Antonio Colaprico [aut],
  Catharina Olsen [aut],
  Alessia Campo [aut],
  Matteo Tiberti [cre, aut],
  Elena Papaleo [aut]
Maintainer: Matteo Tiberti <tiberti@cancer.dk>
Built: R 4.6.0; ; 2026-05-30 13:03:00 UTC; unix
