# Generated by roxygen2: do not edit by hand

export(DMA)
export(FEA)
export(GLS)
export(GMA)
export(GRN)
export(GSEA)
export(LPA)
export(LiftMAF)
export(MAFtoCscape)
export(PRA)
export(PRAtoTibble)
export(RunCscape_somatic)
export(TFinfluence)
export(URA)
export(confidence)
export(getDataGEO)
export(loadMAVISp)
export(moonlight)
export(plotCircos)
export(plotDMA)
export(plotFEA)
export(plotGMA)
export(plotHeatmap)
export(plotMetExp)
export(plotMoonlight)
export(plotMoonlightMet)
export(plotNetworkHive)
export(plotURA)
import(ComplexHeatmap)
import(EpiMix)
import(ExperimentHub)
import(HiveR)
import(RISmed)
import(doParallel)
import(dplyr)
import(easyPubMed)
import(foreach)
import(org.Hs.eg.db)
import(parallel)
import(readr)
import(tibble)
import(tidyHeatmap)
import(tidyr)
importFrom(AnnotationHub,AnnotationHub)
importFrom(BiocGenerics,as.data.frame)
importFrom(DOSE,gseDO)
importFrom(DOSE,simplot)
importFrom(EpiMix,EpiMix_PlotModel)
importFrom(GEOquery,getGEO)
importFrom(GenomicRanges,makeGRangesFromDataFrame)
importFrom(RColorBrewer,brewer.pal)
importFrom(circlize,circlize)
importFrom(circlize,circos.clear)
importFrom(circlize,circos.initialize)
importFrom(circlize,circos.par)
importFrom(circlize,circos.rect)
importFrom(circlize,circos.text)
importFrom(circlize,circos.trackPlotRegion)
importFrom(circlize,colorRamp2)
importFrom(circlize,get.cell.meta.data)
importFrom(clusterProfiler,bitr)
importFrom(data.table,rbindlist)
importFrom(dplyr,filter)
importFrom(dplyr,pull)
importFrom(fgsea,fgsea)
importFrom(fuzzyjoin,genome_left_join)
importFrom(ggplot2,ggsave)
importFrom(gplots,heatmap.2)
importFrom(gplots,redblue)
importFrom(grDevices,dev.list)
importFrom(grDevices,dev.off)
importFrom(grDevices,graphics.off)
importFrom(grDevices,pdf)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(graphics,barplot)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot.new)
importFrom(graphics,text)
importFrom(grid,gpar)
importFrom(magrittr,"%>%")
importFrom(parmigene,knnmi.cross)
importFrom(purrr,keep)
importFrom(purrr,map)
importFrom(purrr,pmap)
importFrom(qpdf,pdf_combine)
importFrom(randomForest,randomForest)
importFrom(readr,parse_guess)
importFrom(readr,read_csv)
importFrom(rlang,set_names)
importFrom(rtracklayer,import.chain)
importFrom(seqminer,tabix.read.table)
importFrom(stats,fisher.test)
importFrom(stats,p.adjust)
importFrom(stringr,str_c)
importFrom(stringr,str_extract)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_split_i)
importFrom(stringr,str_trim)
importFrom(tibble,as_tibble_col)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(tidyr,drop_na)
importFrom(tidyr,nest)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,replace_na)
importFrom(tidyr,separate)
importFrom(tidyr,unite)
importFrom(tidyr,unnest)
importFrom(utils,data)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(withr,with_options)
importMethodsFrom(Biobase,"fvarLabels<-")
importMethodsFrom(Biobase,fvarLabels)
