% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PRAtoTibble.R
\name{PRAtoTibble}
\alias{PRAtoTibble}
\title{PRAtoTibble}
\usage{
PRAtoTibble(dataPRA)
}
\arguments{
\item{dataPRA}{RDA object (list of two) from PRA}
}
\value{
tibble with drivers
}
\description{
This function changes the PRA output to tibble format
}
\examples{
data('dataPRA')
PRAtoTibble(dataPRA)
}
